@@ -346,7 +346,7 @@ draw.key <- function(key, draw = FALSE, vp = NULL)
 
         heights.x <- rep(1, n.row)
         heights.units <- rep("lines", n.row)
-        heights.data <- as.list(1:n.row)
+        heights.data <- vector(mode = "list", length = n.row)
 
         if (length(key$title) > 0)
         {
